function [dens_f_D,distri_f_D] = total_delay_infection_v4a

% preliminaries
    close all
    clear

%% parameters and data

% paras
    mu = 1.63; % of log-normal distribution for incubation - comes from appendix
    sigma = 0.4149; % of log-normal distri incubation - comes from Reinhold
    z = linspace(0,105,105); % Dr data comes in steps of 1 between 0 and 105

% read data
    Dr_density = csvread('Dr_density.csv'); % Read reporting data (Dr>=0) 
                                            % note that data needs to be in same subdirectory as this code                                    

%% descriptive stats data

% interpolate data to get smoother plot
    z = interp1(1:length(z), z, linspace(1, length(z), 5*length(z)+1)); 
    Dr_density = interp1(1:length(Dr_density), Dr_density, linspace(1, length(Dr_density), 5*length(Dr_density)+1)); 
    
% density incubation
    y=lognpdf(z,mu,sigma);

% does Dr integrate to one?
    % integrate density of Dr
        counter = 1;
        for delta = z
            distri_Dr(counter) = integral(@Dr_density_fnct,0, delta); % integrate between 0 and delta
            counter = counter + 1; 
        end
        % answer: nope

    % scaling density and distri
        Dr_density = Dr_density/distri_Dr(end); % divide by probability for highest Dr
                                                % implies that distri_Dr(end) = 1
        distri_Dr = distri_Dr/distri_Dr(end); % do the same for distribution

        
% does D_I (incubation) integrate to one?
    integral_dens_f_lognor = integral(@dens_f_lognor,0, 105);
    fprintf('integrating incubation density yields %g\n', integral_dens_f_lognor)
        
%% integrate and plot total delay D

% integration
    counter = 1;
    for delta = z % get density for D
        dens_f_D(counter) = integral(@convolution_covid,0, delta); % integrate between 0 and delta
        counter = counter + 1; 
    end
        
% checking whether density f_D integrates to one
    integral_dens_f = integral(@density_f_D,0, 105);
    fprintf('integrating density f_D yields %g\n',integral_dens_f)
    
    counter = 1;    
    for delta = z % get distri for D
        distri_f_D(counter) = integral(@density_f_D,0, delta); % integrate between 0 and delta
        counter = counter + 1; 
    end
    
%% compute percentiles and further moments

% prelim
    x = 14.567;
    distri_continuous_f_D(x,0); % this computes the value of the distribution of X for any (continuous x)
                                % this will be employed to compute the percentiles
    fprintf('the probability that total delay is smaller or equal to %g is %g\n', x, distri_continuous_f_D(x,0))                            
   
% percentiles    
    %for c = 0.01:0.01:0.99 % all between 1 and 99 in 1-unit steps
    for c = [0.01 0.025 0.05 0.1 0.25 0.5 0.75 0.8 0.9 0.95 0.975 0.99] % selection of percentiles
        myfun = @(x,c) distri_continuous_f_D(x,c);  % parameterized function
        fun = @(x) myfun(x,c);    % function of x alone
        x = fzero(fun,20);
        fprintf('the %g percentile is %g\n', c*100, x)
    end     

% moments
    mean_D = integral(@mean_f_D, 0, z(end)); % integrate over entire support
    fprintf('the mean of D is %g\n', mean_D)
    
    
%% plot all and save

% plot figure
    xMax = 40;

    figure('name','densities and distributions')
    set(gcf,'position',[10,10,1000,1000])

   
    subplot(2,2,1)
    a = get(gca,'XTickLabel');  
    set(gca,'XTickLabel',a,'fontsize',12)
    plot(z,Dr_density) % plot Dr
    legend('Density infection-report D_r','Location','northeast','Fontsize',12)
    xlabel('Days','Fontsize',14) 
    ylabel('Density','Fontsize',14) 
    xlim([0 xMax])
    title('Panel A','Fontsize',14)
    
    subplot(2,2,2)
    plot(z,distri_Dr)
    a = get(gca,'XTickLabel');  
    set(gca,'XTickLabel',a,'fontsize',12)
    xlabel('Days','Fontsize',14) 
    ylabel('Probability','Fontsize',14) 
    legend('Cumulative distribution\newlineinfection-report D_r','Location','southeast','Fontsize',12)
    xlim([0 xMax])
    title('Panel B','Fontsize',14)
    
    subplot(2,2,3)
    plot(z,y,'r',z,dens_f_D,'b') 
    a = get(gca,'XTickLabel');  
    set(gca,'XTickLabel',a,'fontsize',12)
    xlabel('Days','Fontsize',14) 
    ylabel('Density','Fontsize',14) 
    legend('Lognormal density\newlineincubation D_I','Density total delay D','Location','northeast','Fontsize',12)
    xlim([0 xMax])
    title('Panel C','Fontsize',14)
    
    subplot(2,2,4)
    plot(z,distri_f_D) 
    a = get(gca,'XTickLabel');  
    set(gca,'XTickLabel',a,'fontsize',12)
    xlabel('Days','Fontsize',14)    
    ylabel('Probability','Fontsize',14) 
    legend(('Cumulative distribution\newlinetotal delay D'),'Location','southeast','Fontsize',12)
    xlim([0 xMax])
    title('Panel D','Fontsize',14)

% save figure
    saveas(gcf,'incubation_reporting_total_distributions','meta')    

%% embedded functions
% all variables known in function 'total_delay_infection_.m' are also known
% within these embedded functions

    function distri_value = distri_continuous_f_D(x,const)
        distri_value = interp1(z,distri_f_D,x)-const;
    end

    function dens = Dr_density_fnct(delta_K)
        dens = interp1(z,Dr_density,delta_K);
    end

    function dens = density_f_D(delta_J)
        dens = interp1(z,dens_f_D,delta_J);
    end

    function dens = mean_f_D(delta)
        dens = delta.*interp1(z,dens_f_D,delta);
    end

%     function dens = dens_f_Dr(delta_K)
%         dens = interp1(z,Dr_density,delta_K);
%     end


    function dens = dens_f_lognor(delta_L)
    % the function for the log-normal approximation to incubation
        dens = lognpdf(delta_L,mu,sigma);
    end

    function fg  = convolution_covid(delta_I)

    % the densities
        g = interp1(z,Dr_density, delta-delta_I); % get the density g at delta-delta_I, i.e. g(delta-delta_I)
        f = lognpdf(delta_I,mu,sigma); % get density f(delta_1)

    % convolution    
        fg = f.*g;
    end

end
