clear
close all

% from original paper table 2
parameters.nr = 14; % recovery time in days
parameters.N1 = 83100; % population size in 1000
parameters.eta=0.6;
parameters.a=0.5;

% solution of the system
% initial conditions for probabilites/ shares
p2_0 = 130/1000; % initially sick
p1_0 = parameters.N1 - p2_0;
p3_0 = 0;

%% solving the ODE systems

% general prelims
    BCS=[p1_0 p2_0 p3_0]; % Boundary conditions
    tMax = 200; % end of solution period for ODE
    opts = odeset('RelTol',1e-6,'AbsTol',1e-8,'Refine',1,'NonNegative',[1 1 1 1]); %% options for the ode solver

% full system without intervention
    sol = ode45(@(t,p) ODE_syst_SIR(t,p,parameters), [0 tMax], BCS, opts);

    tout = linspace(0,tMax,tMax+1);
    pout = deval(sol,tout);

    p1 = pout(1,:);
    p2 = pout(2,:);
    N2everCountry1 = pout(3,:);

% with intervention - a is altered to aAlt
    sol_alt = ode45(@(t,p) ODE_syst_SIR_aAlt(t,p,parameters), [0 tMax], BCS, opts);

    pout_alt = deval(sol_alt,tout);

    p1_alt = pout_alt(1,:);
    p2_alt = pout_alt(2,:);
    N2everCountry1_alt = pout_alt(3,:);


%% figures
shift=tMax+1;
figure()
plot(tout(1:shift),p1(1:shift),tout(1:shift),p2(1:shift),tout(1:shift),p1_alt(1:shift),tout(1:shift),p2_alt(1:shift));
legend('p1 - healthy','p2 - infectious','p1 - with intervention','p2 - with intervention')

figure()
plot(tout(1:shift),N2everCountry1(1:shift),tout(1:shift),N2everCountry1_alt);
legend('N2everCountry1','N2everCountry1_alt')

figure()
plot(tout(1:shift),p2(1:shift),tout(1:shift),p2_alt(1:shift),tout(1:shift),N2everCountry1(1:shift),tout(1:shift),N2everCountry1_alt);
legend('infections','infections with intervention', 'accumulated infectious','accum. inf. with intervention')

figure('name','final paper')
% same as earlier one, only xlim added
plot(tout(1:shift),p2(1:shift),tout(1:shift),p2_alt(1:shift),tout(1:shift),N2everCountry1(1:shift),tout(1:shift),N2everCountry1_alt);
legend('infections','infections with intervention', 'accumulated infectious','accum. inf. with intervention')
xlim([30,60])

figure('name','final paper Jena notation')
 set(gcf,'position',[10,10,750,750])
% same as earlier one, only xlim added
plot(tout(1:shift),p2(1:shift),tout(1:shift),p2_alt(1:shift),tout(1:shift),N2everCountry1(1:shift),tout(1:shift),N2everCountry1_alt,'LineWidth',2);
xline(29.5,':','LineWidth',1.5) % vertical line indicating introduction of face masks at T
xline(40,'--','LineWidth',1.5)   % vertical line indicating median total delay D^M=10.5 after T
xline(50,'-.','LineWidth',1.5)   % vertical line indicating Delta of 10 days
xline(60,'-.b','LineWidth',1.5)   % vertical line indicating Delta of 20 days
%legend('Infections control group','Infections mandatory face mask', 'Accumulated infectious','Accum. inf. mandatory face mask','Introduction face masks at T','Median total delay D^m after T','Location','northwest')
legend('control group, I_{control}(t)','face mask, I_{mask}(t)', 'control group accumulated, I_{control}^{ever}(t)','face mask accumulated, I_{mask}^{ever}(t)','Location','northwest')

xlim([0,65])

set(gca,'FontSize',14) % Achsenbeschriftung und Legende title('long-run densities p(a,w) and p(a,b)','FontSize',20)
xlabel('Days','FontSize',14)
ylabel('number of infectious individuals','FontSize',14)

aSize=annotation('textarrow',[0.52 0.49],[0.13 0.13],'String','T');
bSize=annotation('textarrow',[0.57 0.6],[0.16 0.16],'String','T+D^m ');
cSize=annotation('textarrow',[0.69 0.72],[0.13 0.13],'String','\delta={10}');
dSize=annotation('textarrow',[0.81 0.84],[0.16 0.16],'String','\delta={20} ');

aSize.FontSize = 14;bSize.FontSize = 14;cSize.FontSize = 14;dSize.FontSize = 14;

% save figure
    saveas(gcf,'theoretical_effects','meta')    

%% embedded functions
% all variables known in function 'go_SIR_.m' are also known
% within these embedded functions

function dp = ODE_syst_SIR(t,p,parameters)

% parameters
    nr = parameters.nr; % recovery time in days
    N1 = parameters.N1; % population size in 1000
    a = parameters.a; % activity rate of individuals - we divide by N to descale model


dp = [-a * p(1) * p(2)/N1;...
      a * p(1) * p(2)/N1 - 1/nr *p(2);...
      1/nr * p(2)];

end

function dp = ODE_syst_SIR_aAlt(t,p,parameters)

% parameters
    nr = parameters.nr; % recovery time in days
    N1 = parameters.N1; % population size in 1000
%    N2 = parameters.N2; % population size in 1000
    eta = parameters.eta;
    
    if t<40
        a = parameters.a; % activity rate of individuals - we divide by N to descale model
    else
        a = parameters.a-1.25;
%        parameters.a
 %       a
    end


dp = [-a * p(1) * p(2)/N1;...
      a * p(1) * p(2)/N1 - 1/nr *p(2);...
      1/nr * p(2)];

end

